# SOMTimeS: Self-Organizing Maps for TIME Series



## Other relevant papers
If you use this code please cite SOMTimeS paper.

@misc{javed2021somtimes,
      title={SOMTimeS: Self Organizing Maps for Time Series Clustering and its Application to Serious Illness Conversations}, 
      author={Ali Javed and Donna M. Rizzo and Byung Suk Lee and Robert Gramling},
      year={2021},
      eprint={2108.11523},
      archivePrefix={arXiv},
      primaryClass={cs.LG}
}





## Installation

somtime is available on PyPI 

```console
$ pip install somtimes
```

### Install from source


```console
$ python setup.py install
```

## Usage


```
see demo.py for example and explaination of usage
The SOM can cluster time series data.

```
